Structs
Functions
- create_
temporary_ place - Create a temporary Place with a fresh identifier allocated in the arena.
- get_
reverse_ postordered_ blocks - Compute a reverse-postorder of blocks reachable from the entry.
- mark_
instruction_ ids - Sequentially number all instructions and terminals starting from 1.
- mark_
predecessors - DFS from entry, for each successor add the predecessor’s id to the successor’s preds set.
- remove_
dead_ do_ while_ statements - For each block with a
DoWhileterminal whose test block is not in the blocks map, replace the terminal with a Goto to the loop block. - remove_
unnecessary_ try_ catch - For each block with a
Tryterminal whose handler block is not in the blocks map, replace the terminal with a Goto to the try block. - remove_
unreachable_ for_ updates - For each block with a
Forterminal whose update block is not in the blocks map, set update to None.